@@ -86,6 +86,22 @@ private Q_SLOTS:
        qDebug() << id1;
     }
 
+    void testStationIdentifiers()
+    {
+        auto sncf = KnowledgeDb::SncfStationId(QStringLiteral("FRPNO"));
+        QVERIFY(sncf.isValid());
+        QCOMPARE(sncf.toString(), QLatin1String("FRPNO"));
+        sncf = KnowledgeDb::SncfStationId(QStringLiteral("Abc"));
+        QVERIFY(!sncf.isValid());
+        sncf =  KnowledgeDb::SncfStationId(QStringLiteral("CHZID"));
+        QVERIFY(sncf.isValid());
+        QCOMPARE(sncf.toString(), QLatin1String("CHZID"));
+
+        auto vrCode = KnowledgeDb::VRStationCode(QStringLiteral("HSL"));
+        QVERIFY(vrCode.isValid());
+        QCOMPARE(vrCode.toString(), QLatin1String("HSL"));
+    }
+
     void testIBNRLookup()
     {
         auto station = KnowledgeDb::stationForIbnr(IBNR{1234567});
@@ -153,6 +169,10 @@ private Q_SLOTS:
         QVERIFY(station.coordinate.isValid());
         QCOMPARE(toQTimeZone(station.timezone()), QTimeZone("Europe/Zurich"));
         QCOMPARE(station.country, CountryId{"CH"});
+        station = KnowledgeDb::stationForSncfStationId(SncfStationId{"FRHWO"}); // alias for CHGVA...
+        QVERIFY(station.coordinate.isValid());
+        QCOMPARE(toQTimeZone(station.timezone()), QTimeZone("Europe/Zurich"));
+        QCOMPARE(station.country, CountryId{"CH"});
 
         station = KnowledgeDb::stationForSncfStationId(SncfStationId{"NLAMA"}); // vs. SNCB ID of NLASC
         QVERIFY(station.coordinate.isValid());
@@ -160,6 +180,22 @@ private Q_SLOTS:
         QCOMPARE(station.country, CountryId{"NL"});
     }
 
+    void testBenerailStationIdLookup()
+    {
+        auto station = KnowledgeDb::stationForBenerailId({});
+        QVERIFY(!station.coordinate.isValid());
+        QCOMPARE(toQTimeZone(station.timezone()), QTimeZone());
+
+        station = KnowledgeDb::stationForBenerailId(BenerailStationId{"XXXXX"});
+        QVERIFY(!station.coordinate.isValid());
+        QCOMPARE(toQTimeZone(station.timezone()), QTimeZone());
+
+        station = KnowledgeDb::stationForBenerailId(BenerailStationId{"NLASC"});
+        QVERIFY(station.coordinate.isValid());
+        QCOMPARE(toQTimeZone(station.timezone()), QTimeZone("Europe/Amsterdam"));
+        QCOMPARE(station.country, CountryId{"NL"});
+    }
+
     void testCountryDb()
     {
         auto country = KnowledgeDb::countryForId(CountryId{});
@@ -289,6 +325,9 @@ private Q_SLOTS:
         // polar regions
         QCOMPARE(timezoneForCoordinate(-90.0, 0.0), Tz::Undefined);
         QCOMPARE(timezoneForCoordinate(90.0, 0.0), Tz::Undefined);
+
+        // Hong Kong seems problematic on FreeBSD
+        QCOMPARE(timezoneForCoordinate(22.31600, 113.93688), Tz::Asia_Hong_Kong);
     }
 
     void testCountryFromCoordinate()
